package com.siwei.rsmonitoring.service.impl;

import java.util.List;
import com.siwei.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.siwei.rsmonitoring.mapper.TDkAuditflowRecordFjMapper;
import com.siwei.rsmonitoring.domain.TDkAuditflowRecordFj;
import com.siwei.rsmonitoring.service.ITDkAuditflowRecordFjService;

/**
 * 地块核查流程与附件关联Service业务层处理
 * 
 * @author siwei
 * @date 2025-01-22
 */
@Service
public class TDkAuditflowRecordFjServiceImpl implements ITDkAuditflowRecordFjService 
{
    @Autowired
    private TDkAuditflowRecordFjMapper tDkAuditflowRecordFjMapper;

    /**
     * 查询地块核查流程与附件关联
     * 
     * @param id 地块核查流程与附件关联主键
     * @return 地块核查流程与附件关联
     */
    @Override
    public TDkAuditflowRecordFj selectTDkAuditflowRecordFjById(String id)
    {
        return tDkAuditflowRecordFjMapper.selectTDkAuditflowRecordFjById(id);
    }

    /**
     * 查询地块核查流程与附件关联列表
     * 
     * @param tDkAuditflowRecordFj 地块核查流程与附件关联
     * @return 地块核查流程与附件关联
     */
    @Override
    public List<TDkAuditflowRecordFj> selectTDkAuditflowRecordFjList(TDkAuditflowRecordFj tDkAuditflowRecordFj)
    {
        return tDkAuditflowRecordFjMapper.selectTDkAuditflowRecordFjList(tDkAuditflowRecordFj);
    }

    /**
     * 新增地块核查流程与附件关联
     * 
     * @param tDkAuditflowRecordFj 地块核查流程与附件关联
     * @return 结果
     */
    @Override
    public int insertTDkAuditflowRecordFj(TDkAuditflowRecordFj tDkAuditflowRecordFj)
    {
        tDkAuditflowRecordFj.setCreateTime(DateUtils.getNowDate());
        return tDkAuditflowRecordFjMapper.insertTDkAuditflowRecordFj(tDkAuditflowRecordFj);
    }

    /**
     * 修改地块核查流程与附件关联
     * 
     * @param tDkAuditflowRecordFj 地块核查流程与附件关联
     * @return 结果
     */
    @Override
    public int updateTDkAuditflowRecordFj(TDkAuditflowRecordFj tDkAuditflowRecordFj)
    {
        tDkAuditflowRecordFj.setUpdateTime(DateUtils.getNowDate());
        return tDkAuditflowRecordFjMapper.updateTDkAuditflowRecordFj(tDkAuditflowRecordFj);
    }

    /**
     * 批量删除地块核查流程与附件关联
     * 
     * @param ids 需要删除的地块核查流程与附件关联主键
     * @return 结果
     */
    @Override
    public int deleteTDkAuditflowRecordFjByIds(String[] ids)
    {
        return tDkAuditflowRecordFjMapper.deleteTDkAuditflowRecordFjByIds(ids);
    }

    /**
     * 删除地块核查流程与附件关联信息
     * 
     * @param id 地块核查流程与附件关联主键
     * @return 结果
     */
    @Override
    public int deleteTDkAuditflowRecordFjById(String id)
    {
        return tDkAuditflowRecordFjMapper.deleteTDkAuditflowRecordFjById(id);
    }
}
